# -*- encoding: utf-8 -*-
from __future__ import unicode_literals


REGIONS = {
    'ABCDEFGH': 'Africa',
    'JKLMNPR': 'Asia',
    'STUVWXYZ': 'Europe',
    '12345': 'North America',
    '67': 'Oceania',
    '89': 'South America',
}
